@@ -6,6 +6,9 @@ from os import environ
 import random
 import string
 import shutil
+from faker.providers.person.en import Provider
+import numpy as np
+import pandas as pd
 
 
 def pytest_addoption(parser):
@@ -228,3 +231,90 @@ def get_good_meta_data(connector):
     connector.authenticate()
     meta = connector.get_metadata()
     return meta
+
+
+@pytest.fixture(scope="session")
+def random_names(name_type, size):
+    """
+    Generate n-length ndarray of person names.
+    name_type: a string, either first_names or last_names
+    """
+    names = getattr(Provider, name_type)
+    return np.random.choice(names, size=size)
+
+
+@pytest.fixture(scope="session")
+def random_genders(size, p=None):
+    """Generate n-length ndarray of genders."""
+    if not p:
+        # default probabilities
+        p = (0.49, 0.49, 0.01, 0.01)
+    gender = ("M", "F", "O", "")
+    return np.random.choice(gender, size=size, p=p)
+
+
+@pytest.fixture(scope="session")
+def random_dates(start, end, size):
+    """
+    Generate random dates within range between start and end.
+    """
+    # Unix timestamp is in nanoseconds by default, so divide it by
+    # 24*60*60*10**9 to convert to days.
+    divide_by = 24 * 60 * 60 * 10 ** 9
+    start_u = start.value // divide_by
+    end_u = end.value // divide_by
+    return pd.to_datetime(np.random.randint(start_u, end_u, size), unit="D")
+
+
+@pytest.fixture(scope="session")
+def random_numbers(start, end, size):
+    """
+    Generate random numbers within range between start and end.
+    """
+    return np.random.randint(start, end, size)
+
+
+@pytest.fixture(scope="session")
+def five_column_dataset(num_rows):
+    size = num_rows
+    df = pd.DataFrame(columns=['First', 'Last', 'Gender', 'Birthdate'])
+    df['First'] = random_names('first_names', size)
+    df['Last'] = random_names('last_names', size)
+    df['Gender'] = random_genders(size)
+    df['BirthDate'] = random_dates(start=pd.to_datetime('1940-01-01'), end=pd.to_datetime('2022-01-01'), size=size)
+    df['StartDate'] = random_dates(start=pd.to_datetime('1940-01-01'), end=pd.to_datetime('2022-01-01'), size=size)
+    return to_dc_format(df)
+
+
+@pytest.fixture(scope="session")
+def ten_column_dataset(num_rows):
+    size = num_rows
+    df = pd.DataFrame(columns=['First', 'Last', 'Gender', 'Birthdate'])
+    df['First'] = random_names('first_names', size)
+    df['Last'] = random_names('last_names', size)
+    df['Gender'] = random_genders(size)
+    df['BirthDate'] = random_dates(start=pd.to_datetime('1940-01-01'), end=pd.to_datetime('2022-01-01'), size=size)
+    df['StartDate'] = random_dates(start=pd.to_datetime('1940-01-01'), end=pd.to_datetime('2022-01-01'), size=size)
+    df['FavoriteNum'] = random_numbers(start=0, end=1000000, size=size)
+    df['LeastFavoriteNum'] = random_numbers(start=0, end=1000000, size=size)
+    df['NumberOfTimesSaidHello'] = random_numbers(start=0, end=1000000, size=size)
+    df['SaddestAge'] = random_numbers(start=0, end=1000000, size=size)
+    df['NumberOfPushupsDoneEver'] = random_numbers(start=0, end=1000000, size=size)
+    return to_dc_format(df)
+
+
+@pytest.fixture(scope="session")
+def to_dc_format(df):
+    df = df.to_dict("records")
+    return df
+
+
+@pytest.fixture(scope="session")
+def _append():
+    return 0
+
+
+@pytest.fixture(scope="session")
+def _replace():
+    return 1
+
