@@ -433,3 +433,31 @@ class TestGetMetaData:
     def test_returns_data_types(self, get_good_meta_data):
         data = get_good_meta_data
         assert "data_types" in data
+
+
+class TestLoadData:
+    @pytest.mark.destination
+    @pytest.mark.load_data
+    def test_load_data_append(self, connector, good_object_id, m, _append, five_column_dataset):
+        try:
+            connector.load_data(five_column_dataset(100), good_object_id, m, _append, batch_number=1, total_batches=1)
+        except Exception as e:
+            assert False, f"Appending 100 rows of 5-column data raised an exception {e}"
+
+    @pytest.mark.destination
+    @pytest.mark.load_data
+    def test_load_data_replace(self, connector, good_object_id, m, _replace, five_column_dataset):
+        try:
+            connector.load_data(five_column_dataset(100), good_object_id, m, _replace, batch_number=1, total_batches=1)
+        except Exception as e:
+            assert False, f"Replacing 100 rows of 5-column data raised an exception {e}"
+
+    @pytest.mark.destination
+    @pytest.mark.load_data
+    def test_load_data_create_new_table(self, connector, bad_object_id, m, _replace, five_column_dataset):
+        # FIXME: a potential issue here is that i do not have object name validation for "_bad" on an object_id
+        connector.load_data(five_column_dataset(100), bad_object_id, m, _replace, batch_number=1, total_batches=1)
+        connector.authenticate()
+        objects = connector.get_objects()
+        assert bad_object_id in objects[]
+
